@@ -51,7 +51,7 @@ class Monitor:
         self.time = datetime.now().strftime("%Y-%m-%d")
         self.hour = datetime.now().hour
 
-    def run(self, logs_path, host='0.0.0.0', port=5000):
+    def run(self, logs_path='/var/log/event/control_log/', host='0.0.0.0', port=5000):
         log_init('health_monitor', debug=False, log_path=logs_path)
 
         t1 = threading.Thread(target=self.start_scheduler)
